@@ -77,6 +77,7 @@ def utf8_encode(value):
         raise TypeError("value must be basestring, "
                         "not %s" % value_cls_name)
 
+
 _utf8_decoder = codecs.getdecoder('utf-8')
 
 
@@ -859,11 +860,22 @@ class PooledLDAPHandler(LDAPHandler):
         cleaned up when message.clean() is called.
 
         """
-        results = message.connection.result3(message.id, all, timeout)
-
-        # Now that we have the results from the LDAP server for the message, we
-        # don't need the the context manager used to create the connection.
-        message.clean()
+        # message.connection.result3 might throw an exception
+        # so the code must ensure that message.clean() is invoked
+        # regardless of the result3's result. Otherwise, the
+        # connection will be marked as active forever, which
+        # ultimately renders the pool unusable, causing a DoS.
+        try:
+            results = message.connection.result3(message.id, all, timeout)
+        except Exception:
+            # We don't want to ignore thrown
+            # exceptions, raise them
+            raise
+        finally:
+            # Now that we have the results from the LDAP server for
+            # the message, we don't need the the context manager used
+            # to create the connection.
+            message.clean()
 
         return results
 
@@ -1400,9 +1412,24 @@ class BaseLdap(object):
                 pass
             else:
                 try:
-                    obj[k] = v[0]
+                    value = v[0]
                 except IndexError:
-                    obj[k] = None
+                    value = None
+
+                # NOTE(xek): Some LDAP servers return bytes data type
+                # We convert it to string here, so that it is consistent with
+                # the other (SQL) backends.
+                # Bytes data type caused issues in the past, because it could
+                # be cached and then passed into str() method to be used as
+                # LDAP filters, which results in an unexpected b'...' prefix.
+                if isinstance(value, bytes):
+                    try:
+                        value = value.decode('utf-8')
+                    except UnicodeDecodeError:
+                        LOG.error("Error decoding value %r (object id %r).",
+                                  value, res[0])
+                        raise
+                obj[k] = value
 
         return obj
 
