@@ -16,7 +16,6 @@ import abc
 import datetime
 
 from oslo_utils import timeutils
-import six
 
 import keystone.conf
 from keystone import exception
@@ -32,13 +31,12 @@ def revoked_before_cutoff_time():
     return oldest
 
 
-@six.add_metaclass(abc.ABCMeta)
-class RevokeDriverBase(object):
+class RevokeDriverBase(object, metaclass=abc.ABCMeta):
     """Interface for recording and reporting revocation events."""
 
     @abc.abstractmethod
     def list_events(self, last_fetch=None, token=None):
-        """return the revocation events, as a list of objects.
+        """Return the revocation events, as a list of objects.
 
         :param last_fetch:   Time of last fetch.  Return all events newer.
         :param token: dictionary of values from a token, normalized for
@@ -54,7 +52,7 @@ class RevokeDriverBase(object):
 
     @abc.abstractmethod
     def revoke(self, event):
-        """register a revocation event.
+        """Register a revocation event.
 
         :param event: An instance of
             keystone.revoke.model.RevocationEvent
