@@ -759,7 +759,7 @@ class CADFNotificationsForPCIDSSEvents(BaseNotificationTest):
         conf.config(group='security_compliance',
                     minimum_password_age=2)
         conf.config(group='security_compliance',
-                    password_regex='^(?=.*\d)(?=.*[a-zA-Z]).{7,}$')
+                    password_regex=r'^(?=.*\d)(?=.*[a-zA-Z]).{7,}$')
         conf.config(group='security_compliance',
                     password_regex_description='1 letter, 1 digit, 7 chars')
 
@@ -1045,7 +1045,7 @@ class TestEventCallbacks(test_v3.RestfulTestCase):
         Foo()
         project_ref = unit.new_project_ref(domain_id=self.domain_id)
         PROVIDERS.resource_api.create_project(project_ref['id'], project_ref)
-        self.assertItemsEqual(['cb1', 'cb0'], callback_called)
+        self.assertCountEqual(['cb1', 'cb0'], callback_called)
 
     def test_invalid_event_callbacks(self):
         @notifications.listener
